@@ -28,14 +28,13 @@ import datetime
 import six
 
 from sahara.conductor import objects
+from sahara.i18n import _
 from sahara.swift import swift_helper
 from sahara.utils import types
 
 
 def wrap(resource_class):
-    """A decorator which wraps dict returned by a given function into
-    a Resource.
-    """
+    """A decorator wraps dict returned by a given function into a Resource."""
 
     def decorator(func):
         def handle(*args, **kwargs):
@@ -53,8 +52,9 @@ def wrap(resource_class):
 
 
 class Resource(types.FrozenDict):
-    """Represents dictionary as an immutable object, enhancing it with
-    back references and helper methods.
+    """Represents dictionary as an immutable object.
+
+    Enhancing it with back references and helper methods.
 
     For instance, the following dictionary:
     {'first': {'a': 1, 'b': 2}, 'second': [1,2,3]}
@@ -115,7 +115,7 @@ class Resource(types.FrozenDict):
         elif self._is_passthrough_type(entity):
             return entity
         else:
-            raise TypeError("Unsupported type: %s" % type(entity).__name__)
+            raise TypeError(_("Unsupported type: %s") % type(entity).__name__)
 
     def _wrap_list(self, refname, lst):
         newlst = [self._wrap_entity(refname, entity) for entity in lst]
@@ -179,6 +179,14 @@ class NodeGroupTemplateResource(Resource, objects.NodeGroupTemplate):
 class InstanceResource(Resource, objects.Instance):
     _filter_fields = ['tenant_id', 'node_group_id']
 
+    @property
+    def cluster_id(self):
+        return self.node_group.cluster_id
+
+    @property
+    def cluster(self):
+        return self.node_group.cluster
+
 
 class NodeGroupResource(Resource, objects.NodeGroup):
     _children = {
@@ -186,8 +194,8 @@ class NodeGroupResource(Resource, objects.NodeGroup):
         'node_group_template': (NodeGroupTemplateResource, None)
     }
 
-    _filter_fields = ['id', 'tenant_id', 'cluster_id', 'cluster_template_id',
-                      'image_username']
+    _filter_fields = ['tenant_id', 'cluster_id', 'cluster_template_id',
+                      'image_username', 'open_ports']
 
 
 class ClusterTemplateResource(Resource, objects.ClusterTemplate):
@@ -199,6 +207,12 @@ class ClusterTemplateResource(Resource, objects.ClusterTemplate):
 
 
 class ClusterResource(Resource, objects.Cluster):
+
+    def sanitize_cluster_configs(self, cluster_configs):
+        if 'proxy_configs' in cluster_configs:
+            del cluster_configs['proxy_configs']
+        return cluster_configs
+
     _resource_name = 'cluster'
 
     _children = {
@@ -206,10 +220,12 @@ class ClusterResource(Resource, objects.Cluster):
         'cluster_template': (ClusterTemplateResource, None)
     }
 
-    _filter_fields = ['management_private_key', 'extra']
+    _filter_fields = ['management_private_key', 'extra', 'rollback_info',
+                      'sahara_info']
+    _sanitize_fields = {'cluster_configs': sanitize_cluster_configs}
 
 
-##EDP Resources
+# EDP Resources
 
 class DataSource(Resource, objects.DataSource):
     _resource_name = "data_source"
@@ -225,6 +241,10 @@ class JobExecution(Resource, objects.JobExecution):
                 configs[swift_helper.HADOOP_SWIFT_USERNAME] = ""
             if swift_helper.HADOOP_SWIFT_PASSWORD in configs:
                 configs[swift_helper.HADOOP_SWIFT_PASSWORD] = ""
+        if 'trusts' in job_configs:
+            del job_configs['trusts']
+        if 'proxy_configs' in job_configs:
+            del job_configs['proxy_configs']
         return job_configs
 
     def sanitize_info(self, info):
