@@ -19,7 +19,6 @@ import six
 from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
-from sahara.utils.openstack import base as b
 from sahara.utils.openstack import cinder as cinder_client
 from sahara.utils.openstack import neutron as neutron_client
 from sahara.utils.openstack import nova as nova_client
@@ -100,10 +99,9 @@ def _update_limits_for_ng(limits, ng, count):
     sign = lambda x: (1, -1)[x < 0]
     nova = nova_client.client()
     limits['instances'] += count
-    flavor = b.execute_with_retries(nova.flavors.get, ng.flavor_id)
+    flavor = nova.flavors.get(ng.flavor_id)
     limits['ram'] += flavor.ram * count
     limits['cpu'] += flavor.vcpus * count
-    # tmckay-fp this is fine, it will be zero without it
     if ng.floating_ip_pool:
         limits['floatingips'] += count
     if ng.volumes_per_node:
@@ -112,17 +110,21 @@ def _update_limits_for_ng(limits, ng, count):
     if ng.auto_security_group:
         limits['security_groups'] += sign(count)
         # NOTE: +3 - all traffic for private network
-        limits['security_group_rules'] += (
-            (len(ng.open_ports) + 3) * sign(count))
-    limits['ports'] += count
+        if CONF.use_neutron:
+            limits['security_group_rules'] += (
+                (len(ng.open_ports) + 3) * sign(count))
+        else:
+            limits['security_group_rules'] = max(
+                limits['security_group_rules'], len(ng.open_ports) + 3)
+    if CONF.use_neutron:
+        limits['ports'] += count
 
 
 def _get_avail_limits():
     limits = _get_zero_limits()
     limits.update(_get_nova_limits())
     limits.update(_get_neutron_limits())
-    if cinder_client.check_cinder_exists():
-        limits.update(_get_cinder_limits())
+    limits.update(_get_cinder_limits())
     return limits
 
 
@@ -136,40 +138,48 @@ def _sub_limit(total, used):
 def _get_nova_limits():
     limits = {}
     nova = nova_client.client()
-    lim = b.execute_with_retries(nova.limits.get).to_dict()['absolute']
+    lim = nova.limits.get().to_dict()['absolute']
     limits['ram'] = _sub_limit(lim['maxTotalRAMSize'], lim['totalRAMUsed'])
     limits['cpu'] = _sub_limit(lim['maxTotalCores'], lim['totalCoresUsed'])
     limits['instances'] = _sub_limit(lim['maxTotalInstances'],
                                      lim['totalInstancesUsed'])
+    if CONF.use_neutron:
+        return limits
+    if CONF.use_floating_ips:
+        limits['floatingips'] = _sub_limit(lim['maxTotalFloatingIps'],
+                                           lim['totalFloatingIpsUsed'])
+    limits['security_groups'] = _sub_limit(lim['maxSecurityGroups'],
+                                           lim['totalSecurityGroupsUsed'])
+    limits['security_group_rules'] = _sub_limit(lim['maxSecurityGroupRules'],
+                                                0)
     return limits
 
 
 def _get_neutron_limits():
     limits = {}
+    if not CONF.use_neutron:
+        return limits
     neutron = neutron_client.client()
     tenant_id = context.ctx().tenant_id
-    total_lim = b.execute_with_retries(neutron.show_quota, tenant_id)['quota']
+    total_lim = neutron.show_quota(tenant_id)['quota']
 
-    # tmckay-fp here we would just get the limits all the time
-    usage_fip = b.execute_with_retries(
-        neutron.list_floatingips,  tenant_id=tenant_id)['floatingips']
-    limits['floatingips'] = _sub_limit(total_lim['floatingip'],
-                                       len(usage_fip))
+    if CONF.use_floating_ips:
+        usage_fip = neutron.list_floatingips(
+            tenant_id=tenant_id)['floatingips']
+        limits['floatingips'] = _sub_limit(total_lim['floatingip'],
+                                           len(usage_fip))
 
-    usage_sg = b.execute_with_retries(
-        neutron.list_security_groups, tenant_id=tenant_id).get(
-        'security_groups', [])
+    usage_sg = neutron.list_security_groups(
+        tenant_id=tenant_id).get('security_groups', [])
     limits['security_groups'] = _sub_limit(total_lim['security_group'],
                                            len(usage_sg))
 
-    usage_sg_rules = b.execute_with_retries(
-        neutron.list_security_group_rules, tenant_id=tenant_id).get(
-        'security_group_rules', [])
+    usage_sg_rules = neutron.list_security_group_rules(
+        tenant_id=tenant_id).get('security_group_rules', [])
     limits['security_group_rules'] = _sub_limit(
         total_lim['security_group_rule'], len(usage_sg_rules))
 
-    usage_ports = b.execute_with_retries(
-        neutron.list_ports, tenant_id=tenant_id)['ports']
+    usage_ports = neutron.list_ports(tenant_id=tenant_id)['ports']
     limits['ports'] = _sub_limit(total_lim['port'], len(usage_ports))
 
     return limits
@@ -179,7 +189,7 @@ def _get_cinder_limits():
     avail_limits = {}
     cinder = cinder_client.client()
     lim = {}
-    for l in b.execute_with_retries(cinder.limits.get).absolute:
+    for l in cinder.limits.get().absolute:
         lim[l.name] = l.value
 
     avail_limits['volumes'] = _sub_limit(lim['maxTotalVolumes'],
